@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GitHub::Create;
 {
-  $Dist::Zilla::Plugin::GitHub::Create::VERSION = '0.19';
+  $Dist::Zilla::Plugin::GitHub::Create::VERSION = '0.20';
 }
 
 use strict;
@@ -38,7 +38,7 @@ Dist::Zilla::Plugin::GitHub::Create - Create GitHub repo on dzil new
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -47,10 +47,11 @@ Configure git with your GitHub credentials:
     $ git config --global github.user LoginName
     $ git config --global github.password GitHubPassword
 
-Alternatively, the GitHub login token can be used instead of the password
-(note that token-based login has been deprecated by GitHub):
+Alternatively, you can write your credentials in the (optionally GPG-encrypted)
+C<~/.github> file as follows:
 
-    $ git config --global github.token GitHubToken
+    login LoginName
+    password GitHubpassword
 
 then, in your F<profile.ini>:
 
