@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GitHub::Update;
 {
-  $Dist::Zilla::Plugin::GitHub::Update::VERSION = '0.19';
+  $Dist::Zilla::Plugin::GitHub::Update::VERSION = '0.20';
 }
 
 use strict;
@@ -43,7 +43,7 @@ Dist::Zilla::Plugin::GitHub::Update - Update GitHub repo info on release
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -52,10 +52,11 @@ Configure git with your GitHub credentials:
     $ git config --global github.user LoginName
     $ git config --global github.password GitHubPassword
 
-Alternatively, the GitHub login token can be used instead of the password
-(note that token-based login has been deprecated by GitHub):
+Alternatively, you can write your credentials in the (optionally GPG-encrypted)
+C<~/.github> file as follows:
 
-    $ git config --global github.token GitHubToken
+    login LoginName
+    password GitHubpassword
 
 then, in your F<dist.ini>:
 
